/**
 * Copyright 2017 ACCELECOM LTD.  All Rights Reserved.
 *  @file userdemo.cpp
 *  @company 南京艾科朗克信息科技有限公司
 *  @author shuaiw
 *  @modify changfengc
 *  @source encoding UTF-8
 *  @console encoding GB2312
 *  @Formatter GNU Built-in
 *  @brief 一个简单的例子，介绍CXeleTraderApi和CXeleTraderSpi接口的使用。
 *	本例将演示4个业务的基本流程,以及以下查询的结构体构建：
 *   	1. 持仓查询(Position)
 *  	2. 报单查询(Order)
 *  	3. 成交单查询(Trade)
 *   	4. 资金查询(Account)
 *   注意: 配置文件config_userdemo.ini最多可以配置两个交易用户(Trader 0和Trader 1)的信息
 *        默认操作只用Trader 0进行操作。
 */
#include <iostream>
#include <iomanip>
#include <cstring>
#include <cstdio>
#include <cstdlib>
#include <assert.h>
using namespace std;

#include <CXeleTraderApi.hpp>
#include <DemoUtils.h>
#include <sched.h>
#include <unistd.h>
/*
 * 辅助函数: 读取配置文件*.ini
 */

static char g_Password_str[MAX_TRADERS][MEMB_SIZEOF(CXeleFtdcReqUserLoginField,Password)];
static char g_ParticipantID_str[MEMB_SIZEOF(CXeleFtdcInputOrderField, ParticipantID)];
static char g_ClientID_str[MAX_TRADERS][MEMB_SIZEOF(CXeleFtdcInputOrderField, ClientID)];
static char g_AccountID_str[MAX_TRADERS][MEMB_SIZEOF(
		CXeleFtdcQryClientAccountField, AccountID)];
static char g_FrontAddress_str[80];
static char g_QueryFrontAddress_str[80];
static char g_AuthInfo_str[MAX_TRADERS][MEMB_SIZEOF(CXeleFtdcAuthenticationInfoField,
                                       AuthCode)];
static char g_APPID_str[MAX_TRADERS][MEMB_SIZEOF(CXeleFtdcAuthenticationInfoField,
                                    AppID)];

static int iniLoad(char* buf, const char* item, const char* iniName)
{
	static const char sed_fmt[] = "sed 's/%s=\\(.*\\)/\\1/g;tx;d;:x' %s";
	char shell_cmd[160];
	FILE* ini;

	sprintf(shell_cmd, sed_fmt, item, iniName);
	ini = popen(shell_cmd, "r");
	fscanf(ini, "%s\n", buf);
	pclose(ini);
	return 0;
}

static void loadConfigFile(char* iniName)
{
	char buf[32];

	if (iniName == NULL || iniName[0] == 0)
	{
		return;
	}

	memset(g_ParticipantID_str, 0, sizeof(g_ParticipantID_str));
	iniLoad(g_ParticipantID_str, "PARTID", iniName);
	fprintf(stdout, "PARTID:%s\n", g_ParticipantID_str);

	for (int i = 0; i < MAX_TRADERS; ++i)
	{
		sprintf(buf, "PASSWD%d", i);
		memset(g_Password_str[i], 0, sizeof(g_Password_str[i]));
		iniLoad(g_Password_str[i], buf, iniName);
		fprintf(stdout, "%s:%s\n", buf, g_Password_str[i]);

		sprintf(buf, "CLIENTID%d", i);
		memset(g_ClientID_str[i], 0, sizeof(g_ClientID_str[i]));
		iniLoad(g_ClientID_str[i], buf, iniName);
		fprintf(stdout, "%s:%s\n", buf, g_ClientID_str[i]);

		sprintf(buf, "ACCOUNTID%d", i);
		memset(g_AccountID_str[i], 0, sizeof(g_AccountID_str[i]));
		iniLoad(g_AccountID_str[i], buf, iniName);
		fprintf(stdout, "%s:%s\n", buf, g_AccountID_str[i]);

		sprintf(buf, "AUTHCODE%d", i);
		memset(g_AuthInfo_str[i], 0, sizeof(g_AuthInfo_str[i]));
		iniLoad(g_AuthInfo_str[i], buf, iniName);
		fprintf(stdout, "%s:%s\n", buf, g_AuthInfo_str[i]);

		sprintf(buf, "APPID%d", i);
		memset(g_APPID_str[i], 0, sizeof(g_APPID_str[i]));
		iniLoad(g_APPID_str[i], buf, iniName);
		fprintf(stdout, "%s:%s\n", buf, g_APPID_str[i]);
	}

	memset(g_FrontAddress_str, 0, sizeof(g_FrontAddress_str));
	iniLoad(g_FrontAddress_str, "FRONTADDRESS", iniName);
	iniLoad(g_QueryFrontAddress_str, "QUERYFRONTADDRESS", iniName);
	fprintf(stdout, "FRONTADDRESS:%s\n", g_FrontAddress_str);
	fprintf(stdout, "QUERYFRONTADDRESS:%s\n", g_QueryFrontAddress_str);
}

/*
 *
 * 辅助函数: 填写login域
 */
static void example_ReqUserLogin(CXeleFtdcReqUserLoginField *req,
		size_t trader = 0)
{
	memset(req, 0, sizeof(*req));

	snprintf(req->AccountID, sizeof(req->AccountID), "%s", g_AccountID_str[trader]);
	snprintf(req->Password, sizeof(req->Password), "%s", g_Password_str[trader]);
}

static void example_RegisterAuthentication(CXeleFtdcAuthenticationInfoField *authinfo,
                                           size_t trader = 0)
{
	memset(authinfo, 0, sizeof(*authinfo));

	snprintf(authinfo->AuthCode, sizeof(authinfo->AuthCode), "%s", g_AuthInfo_str[trader]);
	snprintf(authinfo->AppID, sizeof(authinfo->AppID), "%s", g_APPID_str[trader]);
}

/*
 * 构造报单
 */
static void example_makeup_order(CXeleFtdcInputOrderField *order,
		size_t trader = 0)
{
	/* 会员代码 */
	snprintf(order->ParticipantID, sizeof(order->ParticipantID), "%s", g_ParticipantID_str);
	/* 客户代码 */
	snprintf(order->ClientID, sizeof(order->ClientID), "%s", g_ClientID_str[trader]);
	/* 合约代码 */
	strcpy(order->InstrumentID, "cu1705");
	/* 报单价格条件 */
	order->OrderPriceType = XELE_FTDC_OPT_LimitPrice;
	/* 买卖方向 */
	order->Direction = XELE_FTDC_D_Buy;
	/* 组合开平标志 */
	order->CombOffsetFlag[0] = XELE_FTDC_OF_Open;
	/* 组合投机套保标志 */
	order->CombHedgeFlag[0] = XELE_FTDC_HF_Speculation;
	/* 价格 */
	order->LimitPrice = 35960;
	/* 数量 */
	order->VolumeTotalOriginal = 10;
	/* 有效期类型 */
	order->TimeCondition = XELE_FTDC_TC_GFD;
	/* 成交量类型 */
	order->VolumeCondition = XELE_FTDC_VC_AV;
	/* 最小成交量 */
	order->MinVolume = 0;
	/* 触发条件 */
	order->ContingentCondition = XELE_FTDC_CC_Immediately;
	/* 止损价 */
	order->StopPrice = 0;
	/*  强平原因 */
	order->ForceCloseReason = XELE_FTDC_FCC_NotForceClose;
	/* 自动挂起标志 */
	order->IsAutoSuspend = 0;
}

/*
 * @class CSimpleOrderManager
 * @brief 利用报单管理场景，演示本API接口调用。
 * @notes CXeleTraderSpi中OnXXX()形式的方法为回调函数，不能阻塞过长时间,
 *        否则，会影响接收其他来自交易柜台的消息。
 */
class CSimpleOrderManager: public CXeleTraderSpi
{
public:
	CXeleFtdcReqUserLoginField login_info;
	CXeleFtdcAuthenticationInfoField auth_info;
	/* 构造函数，需要一个有效的指向CXeleTraderApi实例的指针 */
	CSimpleOrderManager(CXeleTraderApi* pTraderApi) :
			m_pTraderApi(pTraderApi)
	{
	}

	~CSimpleOrderManager()
	{
	}

	/* 当客户端程序与交易柜台建立起通信连接，客户端程序需要进行登录 */
	virtual void OnFrontConnected()
	{
		fprintf(stdout, "{%s}\n", __FUNCTION__);
		example_ReqUserLogin(&login_info);
		m_RspEvent = false;
		example_RegisterAuthentication(&auth_info);
		m_pTraderApi->RegisterAuthentication(&auth_info);
		m_pTraderApi->ReqUserLogin(&login_info, 0);
	}

	/* 当客户端程序与交易柜台通信连接断开时，该方法被调用 */
	virtual void OnFrontDisconnected(int nReason)
	{
		fprintf(stdout, "OnFrontDisconnected:%d\n", nReason);
	}

	/* 当客户端程序发出登录请求之后，该方法会被调用，通知客户端程序登录是否成功  */
	virtual void OnRspUserLogin(CXeleFtdcRspUserLoginField *pRspUserLogin,
			CXeleFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast)
	{

		if (pRspInfo->ErrorID != 0)
		{
			/* 失败， 客户端程序需进行错误处理  */
			PRINT_RSP_ERR(pRspInfo);
			exit(pRspInfo->ErrorID);
		}
		else
		{
			/* 成功，处理数据...  */
			PRINT_RSP(pRspInfo);
		}

		m_RspEvent = true;
	}

	virtual void OnRspOrderInsert(CXeleFtdcInputOrderField *pInputOrder,
			CXeleFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast)
	{
		if (pRspInfo->ErrorID != 0)
		{
			/* 失败， 客户端程序需进行错误处理  */
			PRINT_RSP_ERR(pRspInfo);
			exit(pRspInfo->ErrorID);
		}
		else
		{
			/* 成功，处理数据...  */
			PRINT_RSP(pRspInfo);
		}

		m_RspEvent = true;
	}

	/* 报单回报 */
	virtual void OnRtnOrder(CXeleFtdcOrderField *pOrder)
	{
		printf("OnRtnOrder:\n");
		printf("OrderSysID=[%s]\n", pOrder->OrderSysID);
	}

	/* 针对用户请求的出错通知 */
	virtual void OnRspError(CXeleFtdcRspInfoField *pRspInfo, int nRequestID,
			bool bIsLast)
	{
		PRINT_RSP(pRspInfo);
		/* 客户端程序需进行错误处理 */
		exit(-1);
	}

	/* 持仓查询请求 */
	void ReqQryClientPosition(size_t trader = 0)
	{
		CXeleFtdcQryClientPositionField qryPosition;
		memset(&qryPosition, 0, sizeof(CXeleFtdcQryClientPositionField));
		/* 客户代码 */
		snprintf(qryPosition.AccountID, sizeof(qryPosition.AccountID), "%s",
				g_AccountID_str[trader]);
		/* 合约代码 */
		// strcpy (qryPosition.InstrumentID, "cu1705");
		/* 客户类型 */
		// qryPosition.ClientType = XELE_FTDC_CT_Company;
		m_RspEvent = false;

		m_pTraderApi->ReqQryClientPosition(&qryPosition, 1);
	}

	/* 持仓查询应答 */
	virtual void OnRspQryClientPosition(
			CXeleFtdcRspClientPositionField *pRspClientPosition,
			CXeleFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast)
	{
		if (pRspInfo->ErrorID != 0)
		{
			/* 失败， 客户端程序需进行错误处理  */
			PRINT_RSP_ERR(pRspInfo);
			exit(pRspInfo->ErrorID);
		}
		else
		{
			/*  */
			PRINT_RSP(pRspInfo);
		}

		m_RspEvent = true;
	}

	/* 资金查询请求 */
	void ReqQryClientAccount(size_t trader = 0)
	{
		CXeleFtdcQryClientAccountField qryAccount;
		memset(&qryAccount, 0, sizeof(CXeleFtdcQryClientAccountField));
		/* 资金帐号 */
		snprintf(qryAccount.AccountID, sizeof(qryAccount.AccountID), "%s",
				g_AccountID_str[trader]);
		m_RspEvent = false;

		m_pTraderApi->ReqQryClientAccount(&qryAccount, 1);
	}

	/* 资金查询应答 */
	virtual void OnRspQryClientAccount(
			CXeleFtdcRspClientAccountField *pClientAccount,
			CXeleFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast)
	{
		if (pRspInfo->ErrorID != 0)
		{
			/* 失败， 客户端程序需进行错误处理  */
			PRINT_RSP_ERR(pRspInfo);
			exit(pRspInfo->ErrorID);
		}
		else
		{
			/* 成功，处理数据...  */
			PRINT_RSP(pRspInfo);
		}

		m_RspEvent = true;
	}

	/* 报单查询请求 */
	void ReqQryOrder(size_t trader = 0)
	{
		CXeleFtdcQryOrderField qryOrder;
		memset(&qryOrder, 0, sizeof(CXeleFtdcQryOrderField));
		/* 客户代码 */
		snprintf(qryOrder.AccountID, sizeof(qryOrder.AccountID), "%s",
				g_AccountID_str[trader]);
		m_RspEvent = false;

		m_pTraderApi->ReqQryOrder(&qryOrder, 1);
	}

	/* 报单查询应答 */
	virtual void OnRspQryOrder(CXeleFtdcOrderField* pOrderField,
			CXeleFtdcRspInfoField* pRspInfo, int nRequestID, bool bIsLast)
	{
		if (pRspInfo->ErrorID != 0)
		{
			/* 失败， 客户端程序需进行错误处理  */
			PRINT_RSP_ERR(pRspInfo);
			exit(pRspInfo->ErrorID);
		}
		else
		{
			/* 成功，处理数据...  */
			PRINT_RSP(pRspInfo);
		}

		m_RspEvent = true;
	}

	/* 成交单查询请求 */
	void ReqQryTrade(size_t trader = 0)
	{
		CXeleFtdcQryTradeField qryTrade;
		memset(&qryTrade, 0, sizeof(CXeleFtdcQryTradeField));
		/* 客户代码 */
		snprintf(qryTrade.AccountID, sizeof(qryTrade.AccountID), "%s",
				g_AccountID_str[trader]);
		/* 合约代码 */
		strcpy(qryTrade.InstrumentID, "cu1705");
		/* 成交编号 */
		strcpy(qryTrade.TradeID, "233");
		m_RspEvent = false;

		m_pTraderApi->ReqQryTrade(&qryTrade, 1);
	}

	/* 成交单查询应答 */
	virtual void OnRspQryTrade(CXeleFtdcTradeField* pTradeField,
			CXeleFtdcRspInfoField* pRspInfo, int nRequestID, bool bIsLast)
	{

		if (pRspInfo->ErrorID != 0)
		{
			/* 失败， 客户端程序需进行错误处理  */
			PRINT_RSP_ERR(pRspInfo);
			exit(pRspInfo->ErrorID);
		}
		else
		{
			/* 成功，处理数据...  */
			PRINT_RSP(pRspInfo);
		}

		m_RspEvent = true;
	}

	/* 等待响应事件 */
	void WaitRspEvent()
	{
		do
		{
			sched_yield();
		} while (true != m_RspEvent);
	}

	/* 测试流程：风控管理 */
	bool SimpleRiskManagement()
	{

		sleep(2);
		/* 资金查询应答 */
		ReqQryClientAccount();
		WaitRspEvent();
		/*
		 * 配置两个交易用户 trader=1)
		 * ReqQryClientAccount (1);
		 * WaitRspEvent ();
		 */

		sleep(2);
		/* 持仓查询应答 */
		ReqQryClientPosition();
		WaitRspEvent();
		/*
		 * 配置两个交易用户 trader=1)
		 * ReqQryClientPosition (1);
		 * WaitRspEvent ();
		 */

		sleep(2);
		/* 成交单查询请求 */
		ReqQryTrade();
		WaitRspEvent();
		/*
		 * 配置两个交易用户 trader=1)
		 * ReqQryTrade (1);
		 * WaitRspEvent ();
		 */

		sleep(2);
		/* 报单查询请求 */
		ReqQryOrder();
		WaitRspEvent();
		/*
		 * 配置两个交易用户 trader=1)
		 * ReqQryOrder (1);
		 * WaitRspEvent ();
		 */

		return true;
	}

	/* 测试流程：报单管理 */
	void SimpleOrderManagement()
	{
		/* 等待登入成功 */
		WaitRspEvent();

		/* 检查是否符合风控 */
		if (SimpleRiskManagement())
		{
			/* 满足风控条件,发送报单 */
			CXeleFtdcInputOrderField order;
			memset(&order, 0, sizeof(CXeleFtdcInputOrderField));
			example_makeup_order(&order);
			m_pTraderApi->ReqOrderInsert(&order, 1);
			WaitRspEvent();
		}
	}

private:
	/* 指向CXeleTraderApi实例的指针 */
	CXeleTraderApi* m_pTraderApi;

	/* 响应事件标志 */
	bool m_RspEvent;
};

/*
 * 主函数:
 */
int main(int argc, char* argv[])
{
	/*
	 * 读取config_userdemo.ini
	 */
	loadConfigFile((char*) "config_userdemo.ini");

	std::string msg;

	/*
	 * 创建对象, exchange=1(上期所），0或其他（中金所）
	 */
	int exchangeID = 1;
	CXeleTraderApi* pTraderApi = CXeleTraderApi::CreateTraderApi(exchangeID);
	assert(pTraderApi);
	CSimpleOrderManager som(pTraderApi);
	pTraderApi->RegisterSpi(&som);
	pTraderApi->RegisterFront(g_FrontAddress_str, g_QueryFrontAddress_str);

	/*
	 * 准备login的结构体
	 */
	/*
	 * 订阅相应的流
	 */
	pTraderApi->SubscribePrivateTopic(XELE_TERT_RESTART);
	pTraderApi->SubscribePublicTopic(XELE_TERT_RESTART);
	/*
	 * 开始登录, 使客户端程序开始与交易柜台建立连接
	 */

	pTraderApi->Init();

	/*
	 * 打印API信息
	 */
	fprintf(stdout, "%s\n", pTraderApi->GetVersion());

	/*
	 * 实例流程：报单管理
	 */
	som.SimpleOrderManagement();

	/*
	 * 主线程打印, 等待退出
	 */
	do
	{
		cout << "Input 'q' to disconnect API:";
		getline(cin, msg);
	} while (msg != "q");

	/*
	 * 释放API实例
	 */
	pTraderApi->Release();
	fprintf(stdout, "API release done. Exit Demo.\n");

	return 0;
}
